@@ -1,5 +1,7 @@
 import numpy as np
 
+PCA_CHUNK_SIZE = 100_000
+
 
 def cuml_available() -> bool:
     try:
@@ -17,7 +19,7 @@ def get_pca_embeddings(embs: np.ndarray) -> np.ndarray:
     """
     import cuml
 
-    pca = cuml.PCA(n_components=100)
+    pca = cuml.IncrementalPCA(n_components=100, chunk_size=PCA_CHUNK_SIZE)
     return pca.fit_transform(embs)
 
 
